---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug, triage
assignees: ''

---

#### Software information
Please, provide information about your software:
- Operating System:
- python==
- delu==
- numpy==
- torch==
- pynvml==
- tqdm==

#### Describe the bug
A clear and concise description of what the bug is, what the expected behavior is and a **minimal** example that reproduces the bug.
